@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ca">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
 <context>
     <name>NetFileChooseEdit</name>
     <message>
@@ -297,7 +295,7 @@
     </message>
     <message>
         <source>Enable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;Wireless Network Adapter&lt;/a&gt; first if you want to use the personal hotspot.</source>
-        <translation type="unfinished"></translation>
+        <translation>Activeu primer &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network&apos;&gt;l&apos;adaptador de xarxa sense fil&lt;/a&gt; si voleu usar el punt d&apos;accés personal.</translation>
     </message>
 </context>
 <context>
@@ -1660,4 +1658,4 @@
         <translation>Paràmetres relacionats</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
