@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="fi">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Verkon asetukset</translation>
+        <translation>Verkon asetukset</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkon tunnistus</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Poista ensin &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Lentotila&lt;/a&gt; käytöstä, jos haluat muodostaa yhteyden langattomaan verkkoon</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP ristiriita</translation>
+        <translation>IP ristiriita</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Verkko</translation>
+        <translation>Verkko</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkkokaapeli %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>PPPoE %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistetään &quot;%1&quot;</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; yhdistetty</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; katkaistu</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei voi yhdistää &quot;%1&quot;, tarkista reitittin tai verkkokaapeli.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei voi yhdistää &quot;%1&quot;, pysy lähempänä langatonta reititintä</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteyden muodostaminen &quot;%1&quot; epäonnistui, väärä salasana</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Salasana tarvitaan yhteydelle &quot;%1&quot;</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei löytynyt &quot;%1&quot; 802.11 WLAN-verkkoa</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>Muodosta yhteys &quot;%1&quot;, todennustiedot asetetaan kirjautumisen jälkeen</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Salasana</translation>
+        <translation>Salasana</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Salausavain</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>avain</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxy salasana</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Ryhmän salasana</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Käyttäjänimi</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Nimi (SSID)</translation>
+        <translation>Nimi (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Peruuta</translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Yhdistä</translation>
+        <translation>Yhdistä</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Poista kiinteä yhteys</translation>
+        <translation>Poista kiinteä yhteys</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Kytke kiinteä yhteys</translation>
+        <translation>Kytke kiinteä yhteys</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Poista langaton käytöstä</translation>
+        <translation>Poista langaton käytöstä</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Kytke langaton käyttöön</translation>
+        <translation>Kytke langaton käyttöön</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Poista verkko käytöstä</translation>
+        <translation>Poista verkko käytöstä</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Kytke verkko käyttöön</translation>
+        <translation>Kytke verkko käyttöön</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN pois</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN käyttöön</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Välityspalvelin pois</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Välityspalvelin käyttöön</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Verkon asetukset</translation>
+        <translation>Verkon asetukset</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Palvelut aloitettiin</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistetty: %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Välityspalvelin käytössä</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Yhdistetty</translation>
+        <translation>Yhdistetty</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkko poissa</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Verkkokaapeli irrotettu</translation>
+        <translation>Verkkokaapeli irrotettu</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Ei yhteyttä</translation>
+        <translation>Ei yhteyttä</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Yhdistää</translation>
+        <translation>Yhdistetään</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Yhdistetty, mutta ei internet osoitetta</translation>
+        <translation>Yhdistetty, mutta ei internet osoitetta</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Yhteys epäonnistui</translation>
+        <translation>Yhteys epäonnistui</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP ristiriita</translation>
+        <translation>IP ristiriita</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Langaton verkko</translation>
+        <translation>Langaton verkko</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistetty %1</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Pois</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Kaapeli</translation>
+        <translation>Kiinteä verkko</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Verkko</translation>
+        <translation>Verkko</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Järjestelmän välityspalvelin</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN ei ole yhdistetty tai yhteyden muodostaminen epäonnistui. &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;Mene ohjauspaneeliin&lt;/a&gt; ja tarkista.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Kaapeli</translation>
+        <translation>Kiinteä verkko</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Langaton verkko</translation>
+        <translation>Langaton verkko</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Yhdistä piilotettuun verkkoon</translation>
+        <translation>Yhdistä piilotettuun verkkoon</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Minun verkko</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Muut verkot</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Verkko</translation>
+        <translation>Verkko</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
