@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="nl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Netwerkinstellingen</translation>
+        <translation>Netwerkinstellingen</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Netwerkdetectie</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Schakel de &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;vliegtuigstand&lt;/a&gt; uit als je verbinding wilt maken via bluetooth</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP-conflict</translation>
+        <translation>Ip-conflict</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Netwerk</translation>
+        <translation>Netwerk</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Bekabelde verbinding %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>PPPoE-verbinding %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Bezig met verbinden met ‘%1’</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>Verbonden met ‘%1’</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>Verbinding verbroken met ‘%1’</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Kan geen verbinding maken met ‘%1’ - controleer de router of netwerkkabel</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>Kan geen verbinding maken met ‘%1’ - blijf in de buurt van de draadloze router</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Kan geen verbinding maken met ‘%1’: onjuist wachtwoord</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Wachtwoord vereist om verbinding te maken met ‘%1’</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>Het 802.11 wlan-netwerk ‘%1’ is niet aangetroffen</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>Voer je inloggegevens in om verbinding te kunnen maken met %1</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Wachtwoord</translation>
+        <translation>Wachtwoord</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Privéwachtwoord</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>sleutel</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxywachtwoord</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Groepswachtwoord</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Gebruikersnaam</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Naam (SSID)</translation>
+        <translation>Naam (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Annuleren</translation>
+        <translation>Annuleren</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Verbinden</translation>
+        <translation>Verbinden</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Bekabelde verbinding uitschakelen</translation>
+        <translation>Bekabelde verbinding uitschakelen</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Bekabelde verbinding inschakelen</translation>
+        <translation>Bekabelde verbinding inschakelen</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Draadloze verbinding uitschakelen</translation>
+        <translation>Draadloze verbinding uitschakelen</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Draadloze verbinding inschakelen</translation>
+        <translation>Draadloze verbinding inschakelen</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Netwerk uitschakelen</translation>
+        <translation>Netwerk uitschakelen</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Netwerk inschakelen</translation>
+        <translation>Netwerk inschakelen</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Vpn uitschakelen</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Vpn inschakelen</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Systeemproxy uitschakelen</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Systeemproxy inschakelen</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Netwerkinstellingen</translation>
+        <translation>Netwerkinstellingen</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Meerdere diensten gestart</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Verbonden met ‘%1’</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Systeemproxy ingeschakeld</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Verbonden</translation>
+        <translation>Verbonden</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Netwerk is uitgeschakeld</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Geen netwerkkabel aangesloten</translation>
+        <translation>Geen netwerkkabel aangesloten</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Niet verbonden</translation>
+        <translation>Niet verbonden</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Bezig met verbinden…</translation>
+        <translation>Bezig met verbinden…</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Verbonden, maar geen internettoegang</translation>
+        <translation>Verbonden, maar geen internettoegang</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Verbinding mislukt</translation>
+        <translation>Verbinding mislukt</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IP-conflict</translation>
+        <translation>Ip-conflict</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Draadloos netwerk</translation>
+        <translation>Draadloos netwerk</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Bezig met verbinden met ‘%1’</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Uit</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Bekabeld netwerk</translation>
+        <translation>Bekabeld netwerk</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Netwerk</translation>
+        <translation>Netwerk</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Systeemproxy</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>De vpn is niet goed afgesteld of er kan geen verbinding worden gemaakt. Controleer de instellingen in het &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;instellingencentrum&lt;/a&gt;.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Bekabeld netwerk</translation>
+        <translation>Bekabeld netwerk</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Draadloos netwerk</translation>
+        <translation>Draadloos netwerk</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Verbinden met verborgen netwerk</translation>
+        <translation>Verbinden met verborgen netwerk</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Mijn netwerken</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Overige netwerken</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Netwerk</translation>
+        <translation>Netwerk</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
