@@ -1,301 +1,299 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="bo">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
 <context>
     <name>Bubble</name>
     <message>
         <source>1 new message</source>
-        <translation>འཕྲིན་གསར་1&#xa0;</translation>
+        <translation>འཕྲིན་གསར་1 </translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>སོ་སྔོན་བེད་སྤྱོད་གཏོང་དགོས་ན། ཐོག་མར་&lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;འཕུར་སྐྱོད་དཔེ་རྣམ་&lt;/a&gt;སྒོ་རྒྱོབ།</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
+        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>དྲ་རྒྱ། </translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>%1སྦྲེལ་བཞིན་པ།</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1མཐུད་ཟིན།</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>%1བཅད་ཟིན།</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>%1སྣོན་ཐུབ་མེད་པས། ལམ་སྟོན་ཆས་སམ་དྲ་སྐུད་ལ་ཞིབ་བཤེར་བྱེད་རོགས།</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>%1སྣོན་ཐུབ་མེད་པས། སྐུད་མེད་ལམ་སྟོན་ཆས་དང་ཉེ་འབྲེལ་ཚོད་ལྟ་བྱེད།</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>འབྲེལ་མཐུད་མི་ཐུབ། %1ནང་དུ་བཅུག་མི་ཐུབ། གསང་ཨང་ནོར་འདུག</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>%1འབྲེལ་བར་གསང་ཨང་དགོས།</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 802.11 WLANདྲ་རྒྱ་རྙེད་ཐབས་མེད།</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>“%1”སྦྲེལ་སྐབས་ཐོ་འཇུག་བྱས་རྗེས་ར་སྤྲོད་ཆ་འཕྲིན་སྒྲིག་སྦྱོར་བྱ་དགོས།</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">གསང་ཨང་འཇུག་རོགས།</translation>
+        <translation>གསང་ཨང་། </translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>སྒེར་ལྡེའི་གསང་ཨང་།</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>གསང་ལྡེ།</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>ལས་ཚབ་གསང་ཨང་།</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>ཚོ་པའི་གསང་ཨང་།</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>སྤྱོད་མཁན་མིང་འཇུག་རོགས།</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">དྲ་བའི་མིང་(SSID）ནང་འཇུག་བྱེད་རོགས། </translation>
+        <translation>དྲ་བའི་མིང་(SSID）ནང་འཇུག་བྱེད་རོགས། </translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">འདོར་བ། </translation>
+        <translation>འདོར་བ། </translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">འབྲེལ་མཐུད། </translation>
+        <translation>འབྲེལ་མཐུད། </translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">སྐུད་ཡོད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
+        <translation>སྐུད་ཡོད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">སྐུད་ཡོད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
+        <translation>སྐུད་ཡོད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">སྐུད་མེད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
+        <translation>སྐུད་མེད་དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">སྐུད་མེད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
+        <translation>སྐུད་མེད་དྲ་རྒྱ་སྤྱོད་པ།</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
+        <translation>དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">དྲ་རྒྱ་སྤྱོད་པ།</translation>
+        <translation>དྲ་རྒྱ་སྤྱོད་པ།</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPNཁ་རྒྱག་པ།</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>VPNཁ་ཕྱེ་བ།</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>རྒྱུད་ཁོངས་ལས་ཚབ་སྒོ་རྒྱག་པ།</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>རྒྱུད་ཁོངས་ལས་ཚབ་སྒོ་ཕྱེ་བ།</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">དྲ་རྒྱ་སྒྲིག་འགོད།</translation>
+        <translation>དྲ་རྒྱ་སྒྲིག་འགོད།</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>ཞབས་ཞུ་མང་པོ་ཕྱེ་བ།</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1སྦྲེལ་ཟིན། </translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>རྒྱུད་ཁོངས་ལས་ཚབ་ཕྱེ་བ།</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">སྦྲེལ་ཟིན། </translation>
+        <translation>སྦྲེལ་ཟིན། </translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>དྲ་རྒྱ་ཁ་རྒྱོབ།</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">དྲ་སྐུད་མཐུད་མི་འདུག</translation>
+        <translation>དྲ་སྐུད་མཐུད་མི་འདུག</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">སྦྲེལ་མེད་པ། </translation>
+        <translation>སྦྲེལ་མེད་པ། </translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">སྦྲེལ་བཞིན་པ། </translation>
+        <translation>སྦྲེལ་བཞིན་པ། </translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
+        <translation>དྲ་རྒྱ་དང་འབྲེལ་ཟིན་ཡང་མཉམ་སྦྲེལ་དྲ་རྒྱར་འཛུལ་མི་ཐུབ།</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">འབྲེལ་མཐུད་བྱེད་མ་ཐུབ།</translation>
+        <translation>འབྲེལ་མཐུད་བྱེད་མ་ཐུབ།</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
+        <translation>IPགནས་ཡུལ་འགལ་ཟླ་བྱུང་བ།</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">སྐུད་མེད་དྲ་རྒྱ།</translation>
+        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>%1སྦྲེལ་བཞིན་པ།</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>སྒོ་བརྒྱབ།</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">སྐུད་ཡོད་དྲ་རྒྱ།</translation>
+        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>དྲ་རྒྱ། </translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>རྒྱུད་ཁོངས་ལས་ཚབ།</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>VPNབགོ་སྒྲིག་སྦྲེལ་མེད་པའམ་སྦྲེལ་ཐུབ་མེད། &lt;a style=\&quot;text-decoration: none;\&quot; href=\&quot;go to the control center\&quot;&gt;ཚོད་འཛིན་ལྟེ་གནས་ནས་ཞིབ་བཤེར་བྱོས།&lt;/a&gt;</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">སྐུད་ཡོད་དྲ་རྒྱ།</translation>
+        <translation>སྐུད་ཡོད་དྲ་རྒྱ།</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">སྐུད་མེད་དྲ་རྒྱ།</translation>
+        <translation>སྐུད་མེད་དྲ་རྒྱ།</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">ཡིབ་དྲ་དང་མཐུད་པ།</translation>
+        <translation>ཡིབ་དྲ་དང་མཐུད་པ།</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>ངའི་དྲྭ་རྒྱ།</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>དྲྭ་རྒྱ་གཞན།</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
