@@ -164,6 +164,18 @@ QString NetManager::StrengthLevelString(int level)
     return c_levelString.at(level);
 }
 
+QString NetManager::wpaEapAuthen() const
+{
+    Q_D(const NetManager);
+    return d->wpaEapAuthen();
+}
+
+QString NetManager::wpaEapAuthmethod() const
+{
+    Q_D(const NetManager);
+    return d->wpaEapAuthmethod();
+}
+
 bool NetManager::netCheckAvailable()
 {
     Q_D(NetManager);
@@ -225,16 +237,6 @@ NetManagerPrivate::~NetManagerPrivate()
     m_dataMap.clear();
 }
 
-void NetManagerPrivate::setMonitorNetworkNotify(bool monitor)
-{
-    m_managerThread->setMonitorNetworkNotify(monitor);
-}
-
-void NetManagerPrivate::setUseSecretAgent(bool enabled)
-{
-    m_managerThread->setUseSecretAgent(enabled);
-}
-
 void NetManagerPrivate::setAutoScanInterval(int ms)
 {
     m_managerThread->setAutoScanInterval(ms);
@@ -271,6 +273,16 @@ bool NetManagerPrivate::netCheckAvailable()
     return m_managerThread->NetCheckAvailable();
 }
 
+QString NetManagerPrivate::wpaEapAuthen() const
+{
+    return m_managerThread->wpaEapAuthen();
+}
+
+QString NetManagerPrivate::wpaEapAuthmethod() const
+{
+    return m_managerThread->wpaEapAuthmethod();
+}
+
 void NetManagerPrivate::exec(NetManager::CmdType cmd, const QString &id, const QVariantMap &param)
 {
     qCInfo(DNC) << "UI request exec cmd: " << cmd << ", id: " << id << ", param keys: " << param.keys();
