@@ -1,472 +1,470 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="fi">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
 <context>
     <name>NetworkSecretDialog</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Salasana</translation>
     </message>
     <message>
         <source>Key</source>
-        <translation type="unfinished"></translation>
+        <translation>Avain</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>Avain</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Yksityinen salasana</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxy salasana</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Ryhmän salasana</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Käyttäjänimi</translation>
     </message>
     <message>
         <source>Password required to connect &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistämiseen &lt;font color=&quot;%1&quot;&gt;%2&lt;/font&gt; vaaditaan salasana</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"></translation>
+        <translation>Peruuta</translation>
     </message>
     <message>
         <source>Connect</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistä</translation>
     </message>
     <message>
         <source>Wrong password, please enter again!</source>
-        <translation type="unfinished"></translation>
+        <translation>Väärä salasana, yritä uudelleen!</translation>
     </message>
 </context>
 <context>
     <name>network::sessionservice::NetworkProxy</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkko</translation>
     </message>
     <message>
         <source>System proxy has been cancelled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Järjestelmän välityspalvelin on peruttu.</translation>
     </message>
     <message>
         <source>System proxy is set successfully.</source>
-        <translation type="unfinished"></translation>
+        <translation>Välityspalvelimen asennus onnistui.</translation>
     </message>
 </context>
 <context>
     <name>network::sessionservice::NetworkProxyChains</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkko</translation>
     </message>
     <message>
         <source>Application proxy is set successfully</source>
-        <translation type="unfinished"></translation>
+        <translation>Sovelluksen välityspalvelin on määritetty onnistuneesti</translation>
     </message>
     <message>
         <source>Failed to set the application proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Sovelluksen välityspalvelimen määrittäminen epäonnistui</translation>
     </message>
 </context>
 <context>
     <name>network::sessionservice::NetworkStateHandler</name>
     <message>
         <source>Device state changed</source>
-        <translation type="unfinished"></translation>
+        <translation>Laitteen tila muuttunut</translation>
     </message>
     <message>
         <source>Device state changed, reason unknown</source>
-        <translation type="unfinished"></translation>
+        <translation>Laitteen tila muuttui, syy tuntematon</translation>
     </message>
     <message>
         <source>The device is now managed</source>
-        <translation type="unfinished"></translation>
+        <translation>Laite on nyt hallittu</translation>
     </message>
     <message>
         <source>The device is no longer managed</source>
-        <translation type="unfinished"></translation>
+        <translation>Laitetta ei enää hallita</translation>
     </message>
     <message>
         <source>The device has not been ready for configuration</source>
-        <translation type="unfinished"></translation>
+        <translation>Laite ei ole ollut valmis kokoonpanoa varten</translation>
     </message>
     <message>
         <source>IP configuration could not be reserved (no available address, timeout, etc)</source>
-        <translation type="unfinished"></translation>
+        <translation>IP-määrityksiä ei voitu varata (ei osoitetta, aikakatkaisua jne.)</translation>
     </message>
     <message>
         <source>The IP configuration is no longer valid</source>
-        <translation type="unfinished"></translation>
+        <translation>IP-asetukset ei ole enää voimassa</translation>
     </message>
     <message>
         <source>Passwords were required but not provided</source>
-        <translation type="unfinished"></translation>
+        <translation>Vaadittuja salasanoja ei annettu.</translation>
     </message>
     <message>
         <source>The 802.1X supplicant disconnected from the access point or authentication server</source>
-        <translation type="unfinished"></translation>
+        <translation>802.1X-vastaanotto katkaistiin tukiasemasta tai todennuspalvelimesta</translation>
     </message>
     <message>
         <source>Configuration of the 802.1X supplicant failed</source>
-        <translation type="unfinished"></translation>
+        <translation>802.1X-todennuksen konfiguraatio epäonnistui.</translation>
     </message>
     <message>
         <source>The 802.1X supplicant quitted or failed unexpectedly</source>
-        <translation type="unfinished"></translation>
+        <translation>802.1X-haku poistui tai sen yhteys katkesi odottamatta.</translation>
     </message>
     <message>
         <source>The 802.1X supplicant took too long time to authenticate</source>
-        <translation type="unfinished"></translation>
+        <translation>802.1X-todennuksen vahvistuksessa meni liikaa aikaa.</translation>
     </message>
     <message>
         <source>The PPP service failed to start within the allowed time</source>
-        <translation type="unfinished"></translation>
+        <translation>PPP-palvelin ei käynnistynyt vaaditussa ajassa.</translation>
     </message>
     <message>
         <source>The PPP service disconnected unexpectedly</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteys PPP-palveluun katkesi yllättäen.</translation>
     </message>
     <message>
         <source>The PPP service quitted or failed unexpectedly</source>
-        <translation type="unfinished"></translation>
+        <translation>PPP-palvelu keskeytyi tai epäonnistui yllättäen.</translation>
     </message>
     <message>
         <source>The DHCP service failed to start within the allowed time</source>
-        <translation type="unfinished"></translation>
+        <translation>DHCP-palvelu ei käynnistynyt sallitussa ajassa</translation>
     </message>
     <message>
         <source>The DHCP service reported an unexpected error</source>
-        <translation type="unfinished"></translation>
+        <translation>DHCP-palvelu havaitsi yllättävän virheen</translation>
     </message>
     <message>
         <source>The DHCP service quitted or failed unexpectedly</source>
-        <translation type="unfinished"></translation>
+        <translation>DHCP-palvelu päättyi tai epäonnistui yllättävästi</translation>
     </message>
     <message>
         <source>The shared connection service failed to start</source>
-        <translation type="unfinished"></translation>
+        <translation>Jaetun yhteyspalvelun käynnistys epäonnistui</translation>
     </message>
     <message>
         <source>The shared connection service quitted or failed unexpectedly</source>
-        <translation type="unfinished"></translation>
+        <translation>Jaettu yhteyspalvelu katkesi tai lakkasi yllättäen toimimasta</translation>
     </message>
     <message>
         <source>The AutoIP service failed to start</source>
-        <translation type="unfinished"></translation>
+        <translation>Automaattinen IP-palvelu ei käynnistynyt</translation>
     </message>
     <message>
         <source>The AutoIP service reported an unexpected error</source>
-        <translation type="unfinished"></translation>
+        <translation>AutoIP-palvelu havaitsi odottamattoman virheen</translation>
     </message>
     <message>
         <source>The AutoIP service quitted or failed unexpectedly</source>
-        <translation type="unfinished"></translation>
+        <translation>Automaattinen IP-palvelu poistui tai se katkesi odottamatta</translation>
     </message>
     <message>
         <source>Dialing failed due to busy lines</source>
-        <translation type="unfinished"></translation>
+        <translation>Soitto epäonnistui varatun linjan vuoksi</translation>
     </message>
     <message>
         <source>Dialing failed due to no dial tone</source>
-        <translation type="unfinished"></translation>
+        <translation>Soitto epäonnistui, koska valintaääntä ei kuulunut</translation>
     </message>
     <message>
         <source>Dialing failed due to the carrier</source>
-        <translation type="unfinished"></translation>
+        <translation>Soitto epäonnistui operaattorin vuoksi</translation>
     </message>
     <message>
         <source>Dialing timed out</source>
-        <translation type="unfinished"></translation>
+        <translation>Soitto aikakatkaistiin</translation>
     </message>
     <message>
         <source>Dialing failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Soitto epäonnistui</translation>
     </message>
     <message>
         <source>Modem initialization failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Modeemin alustus epäonnistui</translation>
     </message>
     <message>
         <source>Failed to select the specified GSM APN</source>
-        <translation type="unfinished"></translation>
+        <translation>Määritetyn GSM APN:n valinta epäonnistui</translation>
     </message>
     <message>
         <source>No networks searched</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei haettuja verkkoja</translation>
     </message>
     <message>
         <source>Network registration was denied</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkon rekisteröinti hylättiin</translation>
     </message>
     <message>
         <source>Network registration timed out</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkon rekisteröinti aikakatkaistiin</translation>
     </message>
     <message>
         <source>Failed to register to the requested GSM network</source>
-        <translation type="unfinished"></translation>
+        <translation>Rekisteröityminen pyydettyyn GSM-verkkoon epäonnistui</translation>
     </message>
     <message>
         <source>PIN check failed</source>
-        <translation type="unfinished"></translation>
+        <translation>PIN-tarkastus epäonnistui</translation>
     </message>
     <message>
         <source>Necessary firmware for the device may be missed</source>
-        <translation type="unfinished"></translation>
+        <translation>Tarvittava laiteohjelmisto saattaa puuttua</translation>
     </message>
     <message>
         <source>The device was removed</source>
-        <translation type="unfinished"></translation>
+        <translation>Laite on poistettu</translation>
     </message>
     <message>
         <source>NetworkManager went to sleep</source>
-        <translation type="unfinished"></translation>
+        <translation>NetworkManager vaipui lepotilaan</translation>
     </message>
     <message>
         <source>The device&apos;s active connection was removed or disappeared</source>
-        <translation type="unfinished"></translation>
+        <translation>Laitteen aktiivinen yhteys katkesi tai katkaistiin</translation>
     </message>
     <message>
         <source>A user or client requested to disconnect</source>
-        <translation type="unfinished"></translation>
+        <translation>Käyttäjä tai ohjelma katkaisi yhteyden</translation>
     </message>
     <message>
         <source>The device&apos;s carrier/link changed</source>
-        <translation type="unfinished"></translation>
+        <translation>Laitteen operaattori vaihtui</translation>
     </message>
     <message>
         <source>The device&apos;s existing connection was assumed</source>
-        <translation type="unfinished"></translation>
+        <translation>Laitteen yhteys omaksuttiin</translation>
     </message>
     <message>
         <source>The 802.1x supplicant is now available</source>
-        <translation type="unfinished"></translation>
+        <translation>802.1x-apuohjelma on nyt saatavilla</translation>
     </message>
     <message>
         <source>The modem could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>Modeemia ei löytynyt</translation>
     </message>
     <message>
         <source>The Bluetooth connection timed out or failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Bluetooth aikakatkaistiin tai epäonnistui</translation>
     </message>
     <message>
         <source>GSM Modem&apos;s SIM Card was not inserted</source>
-        <translation type="unfinished"></translation>
+        <translation>GSM-modeemissa ei ole SIM-korttia</translation>
     </message>
     <message>
         <source>GSM Modem&apos;s SIM PIN required</source>
-        <translation type="unfinished"></translation>
+        <translation>SIM-kortin PIN vaaditaan GSM-modeemissa</translation>
     </message>
     <message>
         <source>GSM Modem&apos;s SIM PUK required</source>
-        <translation type="unfinished"></translation>
+        <translation>SIM-kortin PUK vaaditaan GSM-modeemissa</translation>
     </message>
     <message>
         <source>SIM card error in GSM Modem</source>
-        <translation type="unfinished"></translation>
+        <translation>GSM-modeemin SIM-korttivirhe</translation>
     </message>
     <message>
         <source>InfiniBand device does not support connected mode</source>
-        <translation type="unfinished"></translation>
+        <translation>InfiniBand ei tue yhteystilaa</translation>
     </message>
     <message>
         <source>A dependency of the connection failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteyden riippuvuus epäonnistui</translation>
     </message>
     <message>
         <source>RFC 2684 Ethernet bridging error to ADSL</source>
-        <translation type="unfinished"></translation>
+        <translation>ADSL RFC2684 Ethernet-siltausvirhe</translation>
     </message>
     <message>
         <source>ModemManager did not run or quitted unexpectedly</source>
-        <translation type="unfinished"></translation>
+        <translation>Modemin-hallinta ei käynnistynyt tai yhteys katkesi yllättäen</translation>
     </message>
     <message>
         <source>The 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>802.11 WLAN-verkkoa ei löytynyt</translation>
     </message>
     <message>
         <source>A secondary connection of the base connection failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Perusyhteyden toissijainen yhteys epäonnistui</translation>
     </message>
     <message>
         <source>DCB or FCoE setup failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Asennus DCB tai FCoE epäonnistui</translation>
     </message>
     <message>
         <source>Network teaming control failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkkoryhmittelyn hallinta epäonnistui</translation>
     </message>
     <message>
         <source>Modem failed to run or not available</source>
-        <translation type="unfinished"></translation>
+        <translation>Modeemi ei käynnisty tai ei ole käytettävissä</translation>
     </message>
     <message>
         <source>Modem now ready and available</source>
-        <translation type="unfinished"></translation>
+        <translation>Modeemi on valmis ja käytettävissä</translation>
     </message>
     <message>
         <source>SIM PIN is incorrect</source>
-        <translation type="unfinished"></translation>
+        <translation>SIM-kortin PIN on väärin</translation>
     </message>
     <message>
         <source>New connection activation is enqueuing</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteyden aktivointi on jonossa</translation>
     </message>
     <message>
         <source>Parent device changed</source>
-        <translation type="unfinished"></translation>
+        <translation>Emolaite vaihdettu</translation>
     </message>
     <message>
         <source>Management status of parent device changed</source>
-        <translation type="unfinished"></translation>
+        <translation>Emolaitteen hallintatila muuttui</translation>
     </message>
     <message>
         <source>Network cable is unplugged</source>
-        <translation type="unfinished"></translation>
+        <translation>Ei verkkokaapelia</translation>
     </message>
     <message>
         <source>Please make sure SIM card has been inserted with mobile network signal</source>
-        <translation type="unfinished"></translation>
+        <translation>Varmista, että SIM-kortti on asetettu ja verkossa on signaali</translation>
     </message>
     <message>
         <source>Please make sure a correct plan was selected without arrearage of SIM card</source>
-        <translation type="unfinished"></translation>
+        <translation>Varmista, että olet valinnut oikean liittymän ilman SIM-kortin maksurästejä</translation>
     </message>
     <message>
         <source>Failed to activate VPN connection, reason unknown</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN epäonnistui, syy tuntematon</translation>
     </message>
     <message>
         <source>Failed to activate VPN connection</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN epäonnistui</translation>
     </message>
     <message>
         <source>The VPN connection state changed due to being disconnected by users</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN-tila muuttui käyttäjän toimesta</translation>
     </message>
     <message>
         <source>The VPN connection state changed due to being disconnected from devices</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN-tila muuttui, koska yhteys laitteisiin katkesi</translation>
     </message>
     <message>
         <source>VPN service stopped</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN-palvelu pysähtyi</translation>
     </message>
     <message>
         <source>The IP config of VPN connection was invalid</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN IP-määritys oli virheellinen</translation>
     </message>
     <message>
         <source>The connection attempt to VPN service timed out</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN muodostamisyritys aikakatkaistiin</translation>
     </message>
     <message>
         <source>The VPN service start timed out</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN-palvelun käynnistäminen aikakatkaistiin</translation>
     </message>
     <message>
         <source>The VPN service failed to start</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN-palvelun käynnistäminen epäonnistui</translation>
     </message>
     <message>
         <source>The VPN connection password was not provided</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN-salasanaa ei annettu</translation>
     </message>
     <message>
         <source>Authentication to VPN server failed</source>
-        <translation type="unfinished"></translation>
+        <translation>Tunnistautuminen VPN-palvelimeen epäonnistui</translation>
     </message>
     <message>
         <source>The connection was deleted from settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteys poistettiin asetuksista</translation>
     </message>
     <message>
         <source>Enabling hotspot</source>
-        <translation type="unfinished"></translation>
+        <translation>Tukiaseman käyttöönotto</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistetään &quot;%1&quot;</translation>
     </message>
     <message>
         <source>Hotspot enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Tukiasema käytössä</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteys &quot;%1&quot;</translation>
     </message>
     <message>
         <source>Hotspot disabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Tukiasema suljettu</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>Katkaistu &quot;%1&quot;</translation>
     </message>
     <message>
         <source>Unable to share hotspot, please check dnsmasq settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Tukiaseman jakaminen epäonnistui, tarkista dnsmasq asetukset</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteys kohteeseen &quot;%1&quot; ei onnistu, siirry lähemmäksi langatonta reititintä</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteys kohteeseen &quot;%1&quot; ei onnistu. Tarkista reitittimen kaapelit.</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteys epäonnistui, väärä salasana &quot;%1&quot;</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhteysvirhe &quot;%1&quot;</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistääksesi &quot;%1&quot;, aseta kirjautumistiedot</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Salasana vaaditaan yhteydelle &quot;%1&quot;</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>802.11 WLAN-verkkoa &quot;%1&quot; ei löytynyt</translation>
     </message>
     <message>
         <source>Disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>Katkaistu</translation>
     </message>
     <message>
         <source>Airplane mode enabled.</source>
-        <translation type="unfinished"></translation>
+        <translation>Lentotila käytössä</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Verkko</translation>
     </message>
     <message>
         <source>The hardware switch of WLAN Card is off, please switch on as necessary.</source>
-        <translation type="unfinished"></translation>
+        <translation>WLAN-kortin kytkin on pois päältä, kytke se tarvittaessa päälle.</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished"></translation>
+        <translation>Yhdistetty</translation>
     </message>
 </context>
 <context>
@@ -476,4 +474,4 @@
         <translation>Langaton</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
